# comment out when not pre-release
#define prel	rc2

%define fversion %{version}
%define rel	1
%define subrel	2

%define wxver		3.0.3.1
%define wxvershort	3.0

%define use_builtin_wxgtk	0
%{?_with_builtin_wxgtk: %global use_builtin_wxgtk 1}
%{?_without_builtin_wxgtk: %global use_builtin_wxgtk 0}

# use system portaudio (without) or bundled's one (with)
%bcond_without portaudio

Summary:	Free Audio Editor With Effects/Analysis Tools
Name:		audacity
Version:	2.3.1
Release:	%mkrel %{?prel:0.%prel.}%{rel}
License:	GPLv2+
Group:		Sound/Editors and Converters
URL:		http://audacityteam.org/
Source0:	https://www.fosshub.com/Audacity.html/%{name}-minsrc-%{fversion}%{?prel}.tar.xz

%if %{use_builtin_wxgtk}
# get WX_3_0_3_BRANCH from here: https://github.com/wxWidgets/wxWidgets.git
Source1:	https://github.com/wxWidgets/wxWidgets/releases/download/v%{wxver}/wxWidgets-%{wxver}.tar.bz2
%endif

#gw use Alsa by default
Patch6:		audacity-2.0.4-alsa-by-default.patch
#

Patch15:	0005-Fix-building-against-the-system-portaudio-library.patch
# Fix missing Spanish language choice on Linux (mga#24965)
Patch16:	audacity-2.3.1-Fix-missing-Spanish-language-choice-on-Linux.patch

# Patch from Ubuntu
Patch1007:	audacity-2.1.2-workaround-wxwidgets-fit-recovery.patch

# Security fixes
# https://github.com/audacity/audacity/pull/700
Patch2000:  audacity-minsrc-2.3.1-fix-CVE-2020-11867.patch

BuildRequires:	autoconf
BuildRequires:	fftw-devel >= 2.1.4
BuildRequires:	gettext-devel
BuildRequires:	imagemagick
BuildRequires:	pkgconfig(alsa)
BuildRequires:	pkgconfig(flac++)
BuildRequires:	pkgconfig(jack)
BuildRequires:	pkgconfig(id3tag)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(mad)
BuildRequires:	pkgconfig(ogg)
BuildRequires:	cmake
BuildRequires:	pkgconfig(samplerate)
BuildRequires:	pkgconfig(sndfile)
BuildRequires:	pkgconfig(vorbis)
BuildRequires:	pkgconfig(soundtouch) >= 1.3.0
BuildRequires:	pkgconfig(speex)
BuildRequires:	pkgconfig(twolame)
BuildRequires:	wxgtku3.0-devel
BuildRequires:	pkgconfig(zlib)
BuildRequires:	vamp-plugin-sdk-devel
BuildRequires:	pkgconfig(expat)
BuildRequires:	ffmpeg-devel
%if %{with portaudio}
BuildRequires:	pkgconfig(portaudio-2.0)
%endif
BuildRequires:	pkgconfig(lv2)
BuildRequires:	pkgconfig(suil-0)
BuildRequires:	pkgconfig(lilv-0)
#for compressing the help file:
BuildRequires:	zip

%if %{use_builtin_wxgtk}
BuildRequires:	bakefile
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(cppunit)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libmspack)
BuildRequires:  pkgconfig(libnotify) >= 0.7
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(xxf86vm)
BuildRequires:  pkgconfig(zlib)
BuildRequires:	pkgconfig(gtk+-3.0)
%else
BuildRequires:	wxgtk-devel
%endif

Recommends:	%mklibname lame 0

%if %{without portaudio}
Provides:	bundled(portaudio) = 19
%endif
%if %{use_builtin_wxgtk}
Provides:	bundled(wxgtk) = 3.0.3.1
%endif


%description
Audacity is a program that lets you manipulate digital audio waveforms.

In addition to letting you record sounds directly from within the program,
it imports many sound file formats, including WAV, AIFF, MP3 and Ogg/Vorbis.
It supports all common editing operations such as Cut, Copy, and Paste, plus
it will mix tracks and let you apply plug-in effects to any part of a sound.
It also has a built-in amplitude envelope editor, a customizable spectrogram
mode and a frequency analysis window for audio analysis applications.

%prep
%if %{use_builtin_wxgtk}
%setup -q -n %{name}-minsrc-%{fversion} -a 1
%else
%setup -q -n %{name}-minsrc-%{fversion}
%endif

%patch6 -p1 -b .alsa-by-default
%if %{with portaudio}
%patch15 -p1 -b .system-portaudio
%endif
%patch16 -p1 -b .spanish
%patch1007 -p1

%patch2000 -p1

chmod 644 *.txt

#make autoreconf happy
mkdir -p lib-src/{expat,libid3tag,libmad,soundtouch,libogg,libvorbis,libflac}

# fix build on aarch64
for d in $(find . -name "config.sub");do
  cp -af %{_rpmconfigdir}/config.{guess,sub} $(dirname $d)
done

%build
autoreconf -vfi

pushd lib-src/lib-widget-extra
autoreconf -vfi
popd

%if %{use_builtin_wxgtk}
(cd wxWidgets-%{wxver}
 aclocal --force -I $PWD/build/aclocal
 autoconf -f
 libtoolize --copy --force
 CFLAGS="%{optflags} -fno-strict-aliasing" \
 CXXFLAGS="%{optflags} -fno-strict-aliasing" \
 ./configure \
   --prefix=$PWD/../%{name}_binlibs \
   --with-gtk=3 \
   --disable-shared \
   --enable-monolithic \
   --with-libpng=sys \
   --with-libjpeg=sys \
   --with-libtiff=sys \
   --with-zlib=sys \
   --with-expat=sys \
   --with-regex=builtin \
   --with-libmspack
 make -j $(nproc)
 make install
)
%endif

%if %{use_builtin_wxgtk}
export PATH=$PWD/%{name}_binlibs/bin:$PATH
%endif

%configure2_5x \
%if %{use_builtin_wxgtk}
    --enable-static-wx --with-wx-version=%{wxvershort} \
%endif
    --enable-unicode \
    --with-ffmpeg=system \
    --disable-dynamic-loading \
    --with-vorbis=system \
    --with-libmad=system \
    --with-libsndfile=system \
    --with-id3tag=system \
    --with-soundtouch=system \
%if %{with portaudio}
    --with-portaudio=system \
%else
    --with-portaudio=local \
%endif
    --with-lv2=system \
%ifnarch %ix86 x86_64
    --enable-sse=no \
%endif
    --with-libtwolame=system

%make_build

%install
%make_install

%find_lang %{name}

#clean uneeded installed but not packaged
rm -rf %{buildroot}%{_docdir}/*

#gw work around bug #52526
mkdir -p %{buildroot}%{_datadir}/%{name}/help/manual

%files -f %{name}.lang
%{_bindir}/*
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_datadir}/pixmaps/*
%{_datadir}/mime/packages/%{name}.xml
%{_mandir}/man1/%{name}.1*
%{_datadir}/appdata/audacity.appdata.xml


%changelog
* Thu Dec 24 2020 neoclust <neoclust> 2.3.1-1.2.mga7
+ Revision: 1663402
- Add P2000 in order to fix CVE-2020-11867
+ daviddavid <daviddavid>
- add/rebase upstream patch to fix missing Spanish language choice on Linux (mga#24965)
- use system portaudio and conditional portaudio

* Thu Mar 14 2019 zezinho <zezinho> 2.3.1-1.mga7
+ Revision: 1376857
- new version 2.3.1

* Sun Mar 10 2019 daviddavid <daviddavid> 2.2.2-6.mga7
+ Revision: 1373687
- build builtin wxgtk without webkitgtk-3.0 support

* Fri Sep 21 2018 umeabot <umeabot> 2.2.2-5.mga7
+ Revision: 1295120
- Mageia 7 Mass Rebuild

* Fri Jul 13 2018 wally <wally> 2.2.2-4.mga7
+ Revision: 1243432
- fix build on aarch64

* Sat May 05 2018 wally <wally> 2.2.2-3.mga7
+ Revision: 1226268
- add provides for bundled wxgtk and portaudio
+ daviddavid <daviddavid>
- rebuild for new ffmpeg 4.0

* Sun Mar 04 2018 zezinho <zezinho> 2.2.2-2.mga7
+ Revision: 1206554
- new version 2.2.2

* Sat Feb 03 2018 zezinho <zezinho> 2.2.1-2.mga7
+ Revision: 1198703
- rebuild against new vamp-plugins-sdk-2.7.1

* Wed Dec 27 2017 zezinho <zezinho> 2.2.1-1.mga7
+ Revision: 1185992
- build against bundled portaudio till upstream bug is fixed
- new version
- build against system portaudio lib

* Wed Dec 06 2017 zezinho <zezinho> 2.2.0-1.mga7
+ Revision: 1181518
- new version
- use bundled portaudio

* Sat Oct 07 2017 cjw <cjw> 2.1.3-8.mga7
+ Revision: 1169866
- drop unused build dependency on libgnomeprintui

* Fri Jun 09 2017 ghibo <ghibo> 2.1.3-7.mga6
+ Revision: 1107396
- Really apply Patch8.

* Thu Jun 08 2017 ghibo <ghibo> 2.1.3-6.mga6
+ Revision: 1107337
- Fix GUI ComboBox below "Project Rate" in the main window on the bottom of the screen.
- Merged Patch from Ubuntu to fix text fitting problems on recovery dialog window.

* Sat Jun 03 2017 ghibo <ghibo> 2.1.3-5.mga6
+ Revision: 1106196
- Update wxWidgets to release 3.0.3.1, in sync with system one
- Sync internal wxWidgets to 3.0.3.1, same as system one

* Sat Jun 03 2017 akien <akien> 2.1.3-4.mga6
+ Revision: 1106083
- Rebuild for wxgtk 3.0.3.1

* Tue May 02 2017 akien <akien> 2.1.3-3.mga6
+ Revision: 1098267
- Rebuild for ffmpeg 3.3

* Wed Mar 29 2017 ghibo <ghibo> 2.1.3-2.mga6
+ Revision: 1095245
+ rebuild (emptylog)

* Mon Mar 27 2017 ghibo <ghibo> 2.1.3-1.10.mga6
+ Revision: 1094933
- Use bundled wxwidgets 3.0.3-git, linked to gtk3 (added conditional build flag for this).
- Added Patch8 (fix typo in italian po files).
- Added Patch9 to create enough room for string requester to avoid charecters out of the string box.
- Backport Patch1006 from current git release (fixes wx assert in debug build).

* Wed Mar 08 2017 akien <akien> 2.1.2-4.mga6
+ Revision: 1089837
- Rebuild for ffmpeg 3.2.4

* Thu Jun 02 2016 daviddavid <daviddavid> 2.1.2-3.mga6
+ Revision: 1019806
- rebuild for wxgtk3.0 built with GTK2

* Sun May 29 2016 zezinho <zezinho> 2.1.2-2.mga6
+ Revision: 1019312
- rebuild against current gtk to try to fix display glitches

* Thu Jan 21 2016 luigiwalser <luigiwalser> 2.1.2-1.mga6
+ Revision: 926252
- 2.1.2 final
+ wally <wally>
- update URL

* Sun Jan 03 2016 daviddavid <daviddavid> 2.1.2-0.2.rc2.1.mga6
+ Revision: 918922
- new version: 2.1.2_rc2
- fix release tag

* Sat Jan 02 2016 luigiwalser <luigiwalser> 2.1.2-0.2.rc1.mga6
+ Revision: 918465
- rebuild for soundtouch

* Mon Dec 21 2015 zezinho <zezinho> 2.1.2-0.1.rc1.mga6
+ Revision: 913163
- new version
- new version

* Wed Sep 16 2015 shlomif <shlomif> 2.1.1-2.mga6
+ Revision: 879984
- Rebuild for new gcc and wxgtk2.8

* Thu Sep 10 2015 zezinho <zezinho> 2.1.1-1.mga6
+ Revision: 875724
- new version 2.1.1

* Fri Nov 14 2014 cjw <cjw> 2.0.6-2.mga5
+ Revision: 796924
- rebuild for ffmpeg 2.4

* Thu Oct 23 2014 cjw <cjw> 2.0.6-1.mga5
+ Revision: 792547
- 2.0.6
- drop patches 8,10,11: fixed upstream
- enable ffmpeg
- use system portaudio and lv2

* Wed Oct 15 2014 umeabot <umeabot> 2.0.5-5.mga5
+ Revision: 747556
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.0.5-4.mga5
+ Revision: 678040
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/
+ fwang <fwang>
- try build with system ffmpeg

* Tue Mar 04 2014 zezinho <zezinho> 2.0.5-2.mga5
+ Revision: 599570
- bump release to be upper than MGA4 update

* Mon Mar 03 2014 zezinho <zezinho> 2.0.5-1.mga5
+ Revision: 598889
- new version

* Sat Oct 19 2013 umeabot <umeabot> 2.0.4-3.mga4
+ Revision: 534214
- Mageia 4 Mass Rebuild

* Mon Sep 09 2013 fwang <fwang> 2.0.4-2.mga4
+ Revision: 476575
- disable ffmpeg build

* Mon Sep 09 2013 fwang <fwang> 2.0.4-1.mga4
+ Revision: 476570
- more linkage fix
- another link fix
- new version 2.0.4

* Sun Apr 07 2013 rtp <rtp> 2.0.3-2.mga3
+ Revision: 408953
- disable sse build on non x86

* Wed Mar 27 2013 dams <dams> 2.0.3-1.mga3
+ Revision: 405757
- new version 2.0.3

* Tue Feb 12 2013 fwang <fwang> 2.0.2-4.mga3
+ Revision: 398017
- disable ffmpeg build till upstream fix building with recent ffmpeg
- build with ffmpeg (bug#9043)

* Fri Jan 11 2013 umeabot <umeabot> 2.0.2-3.mga3
+ Revision: 346578
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Nov 16 2012 zezinho <zezinho> 2.0.2-2.mga3
+ Revision: 318978
- change group
+ fwang <fwang>
- drop old requires

* Sat Aug 25 2012 fwang <fwang> 2.0.2-1.mga3
+ Revision: 283781
- new version 2.0.2

* Fri Jun 29 2012 fwang <fwang> 2.0.1-1.mga3
+ Revision: 264845
- update brs
- new version 2.0.1

* Wed Apr 18 2012 dams <dams> 2.0.0-1.mga2
+ Revision: 231438
- new version 2.0.0
- rediff patch

* Tue Jan 24 2012 zezinho <zezinho> 1.3.14-1.mga2
+ Revision: 200651
- patch to link to pthread
- patch to fix ffmpeg
- patch to fix gtypes
- rediff patch
- new version

* Mon Sep 19 2011 fwang <fwang> 1.3.13-2.mga2
+ Revision: 145289
- fix build with latest ffmpeg
- rebuild for new libpng

* Tue Jun 07 2011 ahmad <ahmad> 1.3.13-1.mga2
+ Revision: 101629
- Update to 1.3.13
- Rediff the desktopentry patch
- Drop patch1,11
- Update configure options (just '--with-portaudio' works)

* Tue Mar 08 2011 ennael <ennael> 1.3.12-3.mga1
+ Revision: 66674
- clean spec file
- imported package audacity


* Tue Nov 30 2010 Oden Eriksson <oeriksson@mandriva.com> 1.3.12-3mdv2011.0
+ Revision: 603751
- fix build (fix from svn)
- rebuild

* Fri May 07 2010 Götz Waschk <waschk@mandriva.org> 1.3.12-2mdv2010.1
+ Revision: 543138
- trying to fix bug #59129, ffmpeg compatibility

* Mon Apr 12 2010 Götz Waschk <waschk@mandriva.org> 1.3.12-1mdv2010.1
+ Revision: 533678
- new version
- update file list
- remove old icons

* Tue Jan 19 2010 Frederik Himpe <fhimpe@mandriva.org> 1.3.11-1mdv2010.1
+ Revision: 493817
- Update to new version 1.3.11

* Tue Dec 22 2009 Caio Begotti <caio1982@mandriva.org> 1.3.10-2mdv2010.1
+ Revision: 481346
- small release bump since we now have a newer vamp-plugin-sdk

  + Götz Waschk <waschk@mandriva.org>
    - fix soundtouch build dep

* Thu Dec 03 2009 Götz Waschk <waschk@mandriva.org> 1.3.10-1mdv2010.1
+ Revision: 472872
- new version
- drop merged patches 12,13,14
- update file list

* Tue Oct 20 2009 Götz Waschk <waschk@mandriva.org> 1.3.9-2mdv2010.0
+ Revision: 458411
- fix crash in preferences (bug #54752)

* Tue Sep 01 2009 Götz Waschk <waschk@mandriva.org> 1.3.9-1mdv2010.0
+ Revision: 423197
- new version
- add empty help directory (bug #52536)

* Mon Jul 20 2009 Götz Waschk <waschk@mandriva.org> 1.3.8-1mdv2010.0
+ Revision: 398063
- fix autotool calls
- new version
- new source URL
- rediff patches 0,6
- drop patches 1,2,4,7,9,11
- fix build with new soundtouch
- update deps

* Mon Mar 30 2009 Götz Waschk <waschk@mandriva.org> 1.3.7-5mdv2009.1
+ Revision: 362240
- set alsa as default API

* Sun Mar 29 2009 Götz Waschk <waschk@mandriva.org> 1.3.7-4mdv2009.1
+ Revision: 362094
- use the right audio device (bug #49243)
- patch for vamp 1.1 and reenable vamp build
- fix crash in Repeat effect
- make preferences window resizable (bug #49244)

* Sun Mar 08 2009 Frederik Himpe <fhimpe@mandriva.org> 1.3.7-3mdv2009.1
+ Revision: 352938
- Add GTK and X-MandrivaLinux-CrossDesktop menu categories in desktop file
  so that Audacity does not get burried in the More subcategory, because
  Audacity is generally known as the best Linux audio editor, irrespective
  of the used desktop.

* Wed Feb 25 2009 Oden Eriksson <oeriksson@mandriva.com> 1.3.7-2mdv2009.1
+ Revision: 344906
- P10: security fix for CVE-2009-0490 (not needed, but better be safe than sorry)

* Thu Jan 29 2009 Götz Waschk <waschk@mandriva.org> 1.3.7-1mdv2009.1
+ Revision: 335054
- new version
- fix format strings
- switch to internal portaudio
- enable jack
- disable vamp plugin support
- copy pulsaudio patch for portaudio

* Sat Dec 13 2008 Adam Williamson <awilliamson@mandriva.org> 1.3.6-2mdv2009.1
+ Revision: 313998
- drop gcc43.patch (was actually merged upstream)
- rediff desktopentry.patch (for fuzz 0)
- drop the pasuspender script - portaudio now works with Pulse, yay

  + Oden Eriksson <oeriksson@mandriva.com>
    - lowercase ImageMagick

  + Götz Waschk <waschk@mandriva.org>
    - suggest optional libs

* Sat Oct 25 2008 Götz Waschk <waschk@mandriva.org> 1.3.6-1mdv2009.1
+ Revision: 297174
- enable ffmpeg
- new version
- update build deps
- rediff patch 5

* Mon Jul 28 2008 Götz Waschk <waschk@mandriva.org> 1.3.5-3mdv2009.0
+ Revision: 251004
- switch from libresample to libsamplerate to fix bug #42277)

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas

* Wed May 21 2008 Oden Eriksson <oeriksson@mandriva.com> 1.3.5-2mdv2009.0
+ Revision: 209678
- bump release
- added a gcc43 patch from fedora

* Fri May 09 2008 Götz Waschk <waschk@mandriva.org> 1.3.5-1mdv2009.0
+ Revision: 204862
- new version
- drop patches 3,6
- rediff patch 8
- update build deps

* Thu Apr 03 2008 Gustavo De Nardin <gustavodn@mandriva.com> 1.3.4-6mdv2008.1
+ Revision: 192244
- security fix for CVE-2007-6061

* Wed Feb 20 2008 Götz Waschk <waschk@mandriva.org> 1.3.4-5mdv2008.1
+ Revision: 173164
- put back translations (bug #37935)

* Fri Feb 15 2008 Frederic Crozat <fcrozat@mandriva.com> 1.3.4-4mdv2008.1
+ Revision: 169023
- Add script to run audacity inside pasuspender if needed

* Wed Feb 13 2008 Götz Waschk <waschk@mandriva.org> 1.3.4-3mdv2008.1
+ Revision: 166939
- fix desktop entry (bug #37665)

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Sun Dec 09 2007 Funda Wang <fwang@mandriva.org> 1.3.4-2mdv2008.1
+ Revision: 116690
- drop old menu

* Thu Nov 15 2007 Götz Waschk <waschk@mandriva.org> 1.3.4-1mdv2008.1
+ Revision: 108879
- new version
- drop patches 0,1,2,4
- rediff patch 5
- fix buildrequires
- build with wxWidgets 2.8

  + Oden Eriksson <oeriksson@mandriva.com>
    - fix build deps (portaudio-devel)
    - added P3,P4 from debian to make it find the right lame lib
    - added P5 from debian to make it use libresample and optionally libtwolame
      (twolame support is inactive in Mandriva).
    - added P6 from debian to not override CFLAGS
    - added P7 from debian to use external libportaudio
    - generally try to use use external libraries like soundtouch
    - fix build deps

* Fri May 18 2007 Götz Waschk <waschk@mandriva.org> 1.3.3-1mdv2008.0
+ Revision: 28074
- fix buildrequires
- new version
- update flac patch
- remove help file


* Tue Dec 12 2006 Götz Waschk <waschk@mandriva.org> 1.3.2-4mdv2007.0
+ Revision: 95230
- patch for new libflac

* Mon Nov 06 2006 Götz Waschk <waschk@mandriva.org> 1.3.2-3mdv2007.1
+ Revision: 76854
- fix French translation (bug #23469)

* Sun Nov 05 2006 Christiaan Welvaart <cjw@daneel.dyndns.org> 1.3.2-2mdv2007.1
+ Revision: 76690
- patch1: fix soundtouch build on non-x86(-64) archs

* Mon Oct 30 2006 Götz Waschk <waschk@mandriva.org> 1.3.2-1mdv2007.1
+ Revision: 73756
- new version
- drop merged patch 1
- drop obsolete source 4
- disable parallel make

* Sat Oct 14 2006 Götz Waschk <waschk@mandriva.org> 1.3.0-9mdv2006.0
+ Revision: 64568
- bot-friendly buildrequires
- Import audacity

* Sat Oct 14 2006 Götz Waschk <waschk@mandriva.org> 1.3.0-8mdv2007.1
- unpack patches
- build fix

* Thu Jun 22 2006 Götz Waschk <waschk@mandriva.org> 1.3.0-7mdv2007.0
- fix zh locale
- fix build
- xdg menu

* Fri Apr 28 2006 Götz Waschk <waschk@mandriva.org> 1.3.0-6mdk
- upgrade portaudio to svn snapshot

* Fri Apr 28 2006 Götz Waschk <waschk@mandriva.org> 1.3.0-5mdk
- compile with portaudio v19 (requested by Antoine Pitrou)

* Mon Jan 02 2006 Götz Waschk <waschk@mandriva.org> 1.3.0-4mdk
- fix directory ownership

* Wed Dec 14 2005 Götz Waschk <waschk@mandriva.org> 1.3.0-3mdk
- fix bug 20156 (help file location)

* Thu Dec 01 2005 Götz Waschk <waschk@mandriva.org> 1.3.0-2mdk
- fix desktop entry

* Tue Nov 29 2005 Götz Waschk <waschk@mandriva.org> 1.3.0-1mdk
- register mime types
- update file list
- unicode build
- drop patches
- New release 1.3.0

* Sun Aug 28 2005 Herton Ronaldo Krzesinski <herton@mandriva.com> 1.2.3-4mdk
- rebuild, removed use of %%configure2_5x as something behind it is causing
  audacity after built and installed to segfault while running on a new
  installation or while making access to the "Preferences" window, below is
  the error:

  (audacity:12866): Gtk-CRITICAL **: gtk_accel_label_new: assertion `string != NULL' failed

  (audacity:12866): Gtk-CRITICAL **: gtk_misc_set_alignment: assertion `GTK_IS_MISC (misc)' failed

  (audacity:12866): Gtk-CRITICAL **: gtk_container_add: assertion `GTK_IS_WIDGET (widget)' failed

  (audacity:12866): Gtk-CRITICAL **: gtk_accel_label_set_accel_widget: assertion `GTK_IS_ACCEL_LABEL (accel_label)' failed
  Segmentation fault

* Tue Jun 14 2005 Götz Waschk <waschk@mandriva.org> 1.2.3-3mdk
- work around broken wx-config

* Wed Apr 27 2005 Götz Waschk <waschk@mandriva.org> 1.2.3-2mdk
- rebuild for new wxGTK

* Fri Nov 19 2004 Goetz Waschk <waschk@linux-mandrake.com> 1.2.3-1mdk
- New release 1.2.3

* Thu Nov 11 2004 Götz Waschk <waschk@linux-mandrake.com> 1.2.2-4mdk
- rebuild for new wxGTK

* Tue Oct 12 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 1.2.2-3mdk
- C++ fixes
- parallel make now works it seems

* Wed Sep 01 2004 Stew Benedict <sbenedict@mandrakesoft.com> 1.2.2-2mdk
- new icons from André Pascual, Pierre Jarillon (bugzilla #10792)

* Fri Aug 27 2004 Götz Waschk <waschk@linux-mandrake.com> 1.2.2-1mdk
- patch2: fix some missing headers
- drop patch 0
- New release 1.2.2

* Thu Aug 19 2004 Stew Benedict <sbenedict@mandrakesoft.com> 1.2.1-4mdk
- enhanced large icon (Fabien ILLIDE)

* Tue Aug 17 2004 Stew Benedict <sbenedict@mandrakesoft.com> 1.2.1-3mdk
- make icons transparent (bugzilla #10792)

* Tue Jun 08 2004 Götz Waschk <waschk@linux-mandrake.com> 1.2.1-2mdk
- patch for new g++

* Mon May 10 2004 Goetz Waschk <waschk@linux-mandrake.com> 1.2.1-1mdk
- New release 1.2.1

* Thu Apr 29 2004 Götz Waschk <waschk@linux-mandrake.com> 1.2.0-2mdk
- fix build with wxGTK 2.5.1 (pangelo[at]dcc[dot]online.pt)

* Tue Mar 02 2004 Götz Waschk <waschk@linux-mandrake.com> 1.2.0-1mdk
- new version

* Wed Feb 11 2004 Götz Waschk <waschk@linux-mandrake.com> 1.2.0-0.pre4.1mdk
- drop patch 3
- new version

